#
# spec file for package maven-reporting-impl
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           maven-reporting-impl
Version:        3.2.0
Release:        1.2
Summary:        Abstract classes to manage report generation
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://maven.apache.org/shared/%{name}
Source0:        http://archive.apache.org/dist/maven/reporting/%{name}-%{version}-source-release.zip
Source1:        %{name}-build.xml
Patch0:         0001-Remove-dependency-on-junit-addons.patch
BuildRequires:  ant
BuildRequires:  fdupes
BuildRequires:  javapackages-local >= 6
BuildRequires:  maven-doxia-core
BuildRequires:  maven-doxia-logging-api
BuildRequires:  maven-doxia-module-xhtml
BuildRequires:  maven-doxia-module-xhtml5
BuildRequires:  maven-doxia-sink-api
BuildRequires:  maven-doxia-sitetools
BuildRequires:  maven-lib
BuildRequires:  maven-plugin-annotations
BuildRequires:  maven-reporting-api >= 3.1.1
BuildRequires:  maven-shared-utils
BuildRequires:  plexus-utils
BuildRequires:  unzip
BuildArch:      noarch

%description
Abstract classes to manage report generation, which can be run both:

* as part of a site generation (as a maven-reporting-api's MavenReport),
* or as a direct standalone invocation (as a maven-plugin-api's Mojo).

This is a replacement package for maven-shared-reporting-impl

%package javadoc
Summary:        Javadoc for %{name}
Group:          Documentation/HTML

%description javadoc
API documentation for %{name}.

%prep
%setup -q
cp %{SOURCE1} build.xml
%patch0 -p1

# integration tests try to download stuff from the internet
# and therefore they don't work in Build Service
%pom_remove_plugin :maven-invoker-plugin

%build
mkdir -p lib
build-jar-repository -s lib \
    maven-doxia/doxia-core \
    maven-doxia/doxia-logging-api \
    maven-doxia/doxia-module-xhtml \
    maven-doxia/doxia-module-xhtml5 \
    maven-doxia/doxia-sink-api \
    maven-doxia-sitetools/doxia-decoration-model \
    maven-doxia-sitetools/doxia-integration-tools \
    maven-doxia-sitetools/doxia-site-renderer \
    maven/maven-artifact \
    maven/maven-compat \
    maven/maven-core \
    maven/maven-plugin-api \
    maven-plugin-tools/maven-plugin-annotations \
    maven-reporting-api/maven-reporting-api \
    maven-shared-utils/maven-shared-utils \
    plexus/utils

%{ant} \
    jar javadoc

%install
# jar
install -dm 0755 %{buildroot}%{_javadir}/%{name}
install -pm 0644 target/%{name}-%{version}.jar %{buildroot}%{_javadir}/%{name}/%{name}.jar
# pom
install -dm 0755 %{buildroot}%{_mavenpomdir}/%{name}
%{mvn_install_pom} pom.xml %{buildroot}%{_mavenpomdir}/%{name}/%{name}.pom
%add_maven_depmap %{name}/%{name}.pom %{name}/%{name}.jar
# javadoc
install -dm 0755 %{buildroot}%{_javadocdir}/%{name}
cp -pr target/site/apidocs/* %{buildroot}%{_javadocdir}/%{name}/
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%license LICENSE NOTICE

%files javadoc
%{_javadocdir}/%{name}
%license LICENSE NOTICE

%changelog
* Sun Sep 24 2023 Fridrich Strba <fstrba@suse.com>
- Upgrade to version 3.2.0
  * Improvement:
    + MSHARED-1099 - Render with a skin when report is run in
    standalone mode
  * Dependency upgrades:
    + MSHARED-1120 - Upgrade Maven Reporting API to 3.1.1
    + MSHARED-1121 - Upgrade plugins and components in project and
    ITs
- Modified patch:
  * 0001-Remove-dependency-on-junit-addons.patch
    + rediff
* Wed Sep  6 2023 Fridrich Strba <fstrba@suse.com>
- Remove unnecessary dependency on xmvn tools and parent pom
* Fri Mar 11 2022 Fridrich Strba <fstrba@suse.com>
- Upgrade to version 3.1.0
  * API sync with maven-reporting-api 3.1.0
- Modified patch:
  * 0001-Remove-dependency-on-junit-addons.patch
    + rediff
* Wed Mar 11 2020 Fridrich Strba <fstrba@suse.com>
- Fix build against newer doxia that requires html5 module
* Fri Mar 29 2019 Fridrich Strba <fstrba@suse.com>
- Initial packaging of maven-reporting-impl 3.0.0
- Generate and customize ant build.xml file
